@@ -5,10 +5,9 @@ use strict;
 use vars qw( $VERSION );
 BEGIN { eval { require warnings } ? 'warnings'->import : ( $^W = 1 ) }
 
-use Waft 0.9907 ();
+use Waft 0.9910 ();
 
-$VERSION = '0.01';
-$VERSION = eval $VERSION;
+$VERSION = '0.02';
 
 $Waft::JS::Name = 'Waft.JS';
 
@@ -26,7 +25,7 @@ sub convert_text_part {
         ( my $method, $text_part ) = split / \b /xms, $text_part, 2;
 
         if ($method eq 'make_url' or $method eq 'url') {
-            $code .= q{$Waft::Self->output_js_make_url_script;};
+            $code .= q{$__self->output_js_make_url_script;};
         }
 
         $code .= $self->next($text_part, $break);
@@ -226,7 +225,7 @@ Yuji Tamashiro, E<lt>yuji@tamashiro.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Yuji Tamashiro
+Copyright (C) 2008, 2009 by Yuji Tamashiro
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
